==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/Stacked100ColumnBucketCalculator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StackedColumnBucketCalculator } from "./StackedColumnBucketCalculator";
import { StackedSeriesBase } from "./StackedSeriesBase";
import { ColumnFragment } from "./ColumnFragment";
import { ScalerParams } from "./ScalerParams";
import { typeCast, markType } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
export let Stacked100ColumnBucketCalculator = /*@__PURE__*/ (() => {
    class Stacked100ColumnBucketCalculator extends StackedColumnBucketCalculator {
        constructor(a) {
            super(a);
        }
        getBucket(a) {
            return super.getBucket(a);
        }
        getBucket1(a, b, c, d, e, f) {
            let g = typeCast(StackedSeriesBase.$, this.c.cw);
            let h = [NaN, NaN, NaN];
            let i = typeCast(ColumnFragment.$, a);
            if (i == null || i.logicalSeriesLink == null) {
                return h;
            }
            let j = g.getEffectiveViewport1(this.c);
            let k = a.valueColumn.item(c);
            let l = 0;
            let m = NaN;
            let n = NaN;
            let o = Number.NEGATIVE_INFINITY;
            let p = Number.POSITIVE_INFINITY;
            let q = 0;
            let r = Math.min(g.xd != null ? g.xd.length : 0, g.xc != null ? g.xc.length : 0);
            let s = c * this.d;
            let t = Math.min(s + this.d - 1, r - 1);
            if (s <= t) {
                for (let u = s; u <= t; ++u) {
                    k = a.valueColumn.item(u);
                    q = Math.abs(g.xd[u]) + g.xc[u];
                    if (k < l) {
                        p = Math.min(p, (i.logicalSeriesLink.a8._inner[u] + k) / q * 100);
                        o = Math.max(o, i.logicalSeriesLink.a8._inner[u] / q * 100);
                    }
                    else {
                        p = Math.min(p, i.logicalSeriesLink.a7._inner[u] / q * 100);
                        o = Math.max(o, (i.logicalSeriesLink.a7._inner[u] + k) / q * 100);
                    }
                    if (!isNaN_(m)) {
                        if (!isNaN_(p)) {
                            m = Math.min(m, p);
                            n = Math.max(n, p);
                        }
                        if (!isNaN_(o)) {
                            m = Math.min(m, o);
                            n = Math.max(n, o);
                        }
                    }
                    else {
                        m = p;
                        n = o;
                    }
                }
            }
            let v = new ScalerParams(0, d, e, i.fragmentYAxis.ch, j);
            h = [f.f._inner[b - this.e][0], i.fragmentYAxis.ej(n, v), i.fragmentYAxis.ej(m, v)];
            return h;
        }
    }
    Stacked100ColumnBucketCalculator.$t = markType(Stacked100ColumnBucketCalculator, 'Stacked100ColumnBucketCalculator', StackedColumnBucketCalculator.$);
    return Stacked100ColumnBucketCalculator;
})();

==> igniteui-angular-charts-18.2.0-beta.0.tgz: package/esm2015/lib/Stacked100ColumnBucketCalculator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StackedColumnBucketCalculator } from "./StackedColumnBucketCalculator";
import { StackedSeriesBase } from "./StackedSeriesBase";
import { ColumnFragment } from "./ColumnFragment";
import { ScalerParams } from "./ScalerParams";
import { typeCast, markType } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
export let Stacked100ColumnBucketCalculator = /*@__PURE__*/ (() => {
    class Stacked100ColumnBucketCalculator extends StackedColumnBucketCalculator {
        constructor(a) {
            super(a);
        }
        getBucket(a) {
            return super.getBucket(a);
        }
        getBucket1(a, b, c, d, e, f) {
            let g = typeCast(StackedSeriesBase.$, this.c.cy);
            let h = [NaN, NaN, NaN];
            let i = typeCast(ColumnFragment.$, a);
            if (i == null || i.logicalSeriesLink == null) {
                return h;
            }
            let j = g.getEffectiveViewport1(this.c);
            let k = a.valueColumn.item(c);
            let l = 0;
            let m = NaN;
            let n = NaN;
            let o = Number.NEGATIVE_INFINITY;
            let p = Number.POSITIVE_INFINITY;
            let q = 0;
            let r = Math.min(g.aar != null ? g.aar.length : 0, g.aaq != null ? g.aaq.length : 0);
            let s = c * this.d;
            let t = Math.min(s + this.d - 1, r - 1);
            if (s <= t) {
                for (let u = s; u <= t; ++u) {
                    k = a.valueColumn.item(u);
                    q = Math.abs(g.aar[u]) + g.aaq[u];
                    if (k < l) {
                        p = Math.min(p, (i.logicalSeriesLink.a8._inner[u] + k) / q * 100);
                        o = Math.max(o, i.logicalSeriesLink.a8._inner[u] / q * 100);
                    }
                    else {
                        p = Math.min(p, i.logicalSeriesLink.a7._inner[u] / q * 100);
                        o = Math.max(o, (i.logicalSeriesLink.a7._inner[u] + k) / q * 100);
                    }
                    if (!isNaN_(m)) {
                        if (!isNaN_(p)) {
                            m = Math.min(m, p);
                            n = Math.max(n, p);
                        }
                        if (!isNaN_(o)) {
                            m = Math.min(m, o);
                            n = Math.max(n, o);
                        }
                    }
                    else {
                        m = p;
                        n = o;
                    }
                }
            }
            let v = new ScalerParams(0, d, e, i.fragmentYAxis.ch, j);
            h = [f.f._inner[b - this.e][0], i.fragmentYAxis.el(n, v), i.fragmentYAxis.el(m, v)];
            return h;
        }
    }
    Stacked100ColumnBucketCalculator.$t = markType(Stacked100ColumnBucketCalculator, 'Stacked100ColumnBucketCalculator', StackedColumnBucketCalculator.$);
    return Stacked100ColumnBucketCalculator;
})();
